@@ -259,6 +259,11 @@ sub is_square_free {
   _validate_positive_integer($n);
   return Math::Prime::Util::PP::is_square_free($n);
 }
+sub is_carmichael {
+  my($n) = @_;
+  #_validate_positive_integer($n);
+  return Math::Prime::Util::PP::is_carmichael($n);
+}
 
 
 sub lucas_sequence {
@@ -606,6 +611,9 @@ sub fordivisors (&$) {    ## no critic qw(ProhibitSubroutinePrototypes)
 sub forpart (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
   Math::Prime::Util::PP::forpart(@_);
 }
+sub forcomp (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
+  Math::Prime::Util::PP::forcomp(@_);
+}
 sub forcomb (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
   Math::Prime::Util::PP::forcomb(@_);
 }
